@@ -93,8 +93,7 @@ sub parse() {
 	$count->{syns} = 0;
 
 	while (<$fh>) {
-		# multiplatform chomp
-		s/\015?\012?$//;
+		chomp;
 
 		# initialise
 		if (/^\*NEWRECORD/) {
@@ -103,11 +102,9 @@ sub parse() {
 			$id       = undef;
 		}
 
-		DEBUG '<' . $_ . '>';
-
 		# save on new line
 		if (/^$/) {
-			LOGDIE 'Could not parse heading\'s label.'
+			LOGDIE 'Something went wrong. Could not parse heading\'s label.'
 			  unless defined $label;
 			$count->{headings}++;
 			WARN "Duplicate heading found for $id"
@@ -143,16 +140,13 @@ sub parse() {
 	}
 	close $fh;
 
-	LOGDIE 'Could not parse any headings.'
-	  unless defined $count->{headings};
-
 	INFO "Loaded "
 	  . $count->{headings}
 	  . " headings and "
 	  . $count->{syns}
 	  . " synonyms";
-
-	1;
+	  
+	  1;
 }
 
 1;
